@@ -14,6 +14,8 @@ use Time::HiRes qw(gettimeofday tv_interval);
 use base 'Exporter';
 our @EXPORT_OK = qw(plot plot3d plotlines plotpoints);
 
+our $VERSION = 0.05;
+
 # when testing plots with ASCII i/o, this is the unit of test data
 my $testdataunit_ascii = "10 ";
 
@@ -550,7 +552,19 @@ sub plot
         {
           if (my @badKeys = grep {!defined $curveOptionsSet{$_}} keys %$option)
           {
-            barf "plot() got some unknown curve options: (@badKeys)";
+            my @bad_plot_options = grep {$plotOptionsSet{$_}} @badKeys;
+
+            if( !@bad_plot_options )
+            {
+              barf "plot() got some unknown curve options: (@badKeys)";
+            }
+            else
+            {
+              barf
+                "plot() got some unknown curve options: (@badKeys)\n" .
+                "Of these, the following are valid PLOT options: @bad_plot_options\n" .
+                "All plot options must be given before all curve options";
+            }
           }
         }
       }
@@ -915,6 +929,8 @@ EOM
     #    etc) tossing out any test-plot data. The point of the plot-command
     #    testing is to make sure the command is valid, so any out-of-boundedness
     #    of the test data is irrelevant
+    #
+    # 3. image grid complaints
     if(defined $flags && $flags =~ /ignore_known_test_failures/)
     {
       $fromerr =~ s/^gnuplot>\s*(?:$testdataunit_ascii|e\b).*$ # report of the actual invalid command
@@ -933,6 +949,10 @@ EOM
       $fromerr =~ s/^gnuplot>\s*plot.*$                        # the test plot command
                     \n^\s+\^\s*$                               # ^ mark pointing to where the error happened
                     \n^.*all\s*points.*undefined.*$//xmg;      # actual 'invalid range' complaint
+
+      # 'with image' plots can complain about an uninteresting domain. Exact error:
+      # GNUPLOT (plot_image):  Image grid must be at least 4 points (2 x 2).
+      $fromerr =~ s/^.*Image grid must be at least.*$//mg;
     }
 
     $fromerr =~ s/^\s*(.*?)\s*/$1/;
